@@ -5,7 +5,7 @@ Locale::SubCountry - Convert state, province, county etc. names to/from ISO 3166
 =head1 SYNOPSIS
 
     my $country_code = 'GB';
-    my $UK = new Locale::SubCountry($country_code);
+    my $UK = Locale::SubCountry->new($country_code);
     if ( not $UK )
     {
         die "Invalid code $country_code\n";
@@ -16,7 +16,7 @@ Locale::SubCountry - Convert state, province, county etc. names to/from ISO 3166
         print($UK->regional_division('DGY'),"\n");   # SCT (Scotland)
     }
 
-    my $australia = new Locale::SubCountry('Australia');
+    my $australia = Locale::SubCountry->new('Australia');
     if ( not $australia )
     {
         die "Invalid code: Australia\n";
@@ -50,7 +50,7 @@ Locale::SubCountry - Convert state, province, county etc. names to/from ISO 3166
 
     # Methods for country codes and names
 
-    my $world = new Locale::SubCountry::World;
+    my $world = Locale::SubCountry::World->new();
     my @all_countries     = $world->all_full_names;
     my @all_country_codes = $world->all_codes;
 
@@ -96,7 +96,7 @@ sure that your chosen method is acting on the correct type of object.
     full_name_code_hash
 
 
-=head2 new Locale::SubCountry::World
+=head2  Locale::SubCountry::World->new()
 
 The C<new> method creates an instance of a world country object. This must be
 called before any of the following methods are invoked. The method takes no
@@ -125,7 +125,7 @@ Given a world object, returns an array of all country IS) 3166-1 codes,
 sorted alphabetically.
 
 
-=head2 new Locale::SubCountry
+=head2 Locale::SubCountry->new()
 
 The C<new> method creates an instance of a sub country object. This must be
 called before any of the following methods are invoked. The method takes a
@@ -185,7 +185,7 @@ or "unknown" if no match is found.
 
 Given a sub country object, the C<regional_division> method takes the
 ISO 3166-2 code of a sub country and returns the sub country's
-regionional_division. This is, an alphanumeric code. The regional_division
+regional_division. This is an alphanumeric code. The regional_division
 is returned as a capitalised string,  or "unknown" if no match is found.
 
 =head2 has_sub_countries
@@ -312,18 +312,16 @@ this module.
 
 Mark Summerfield and Guy Fraser provided the list of UK counties.
 
-TJ Mather supplied the FIPS codes and many ammendments to the sub country data
+TJ Mather supplied the FIPS codes and many amendments to the sub country data
 
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014 Kim Ryan. All rights reserved.
+Copyright (c) 2015 Kim Ryan. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
-
-
 =cut
 
 #-------------------------------------------------------------------------------
@@ -337,7 +335,7 @@ use Locale::SubCountry::Data;
 #-------------------------------------------------------------------------------
 
 package Locale::SubCountry::World;
-our $VERSION = '1.63';
+our $VERSION = '1.64';
 
 # Define all the methods for the 'world' class here. Note that because the
 # name space inherits from the Locale::SubCountry name space, the
@@ -393,7 +391,7 @@ sub all_codes
 #-------------------------------------------------------------------------------
 
 package Locale::SubCountry;
-our $VERSION = '1.63';
+our $VERSION = '1.64';
 
 #-------------------------------------------------------------------------------
 # Initialization code must be run first to create global data structure.
